@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.16 $
+//$Revision: 1.17 $
 #include "hk_actionquery.h"
 #include "hk_database.h"
 
@@ -88,7 +88,7 @@ void hk_actionquery::set_sql(const char* s,unsigned long l)
     if (driver_specific_sql(s))
     {
     p_length=l;
-     p_sql=(char*)s;
+     p_sql=s;
     }
  p_private->p_administerdata=false;
 }
@@ -118,7 +118,7 @@ void   hk_actionquery::before_source_vanishes(void)
 }
 
 
-bool    hk_actionquery::driver_specific_sql(const char*s)
+bool    hk_actionquery::driver_specific_sql(const char*)
 {
     return false;
 }
