@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.64 $
+//$Revision: 1.67 $
 #include "hk_column.h"
 #include "hk_datasource.h"
 #include "hk_dsdatavisible.h"
@@ -316,7 +316,7 @@ void hk_column::set_asstring(const hk_string& s,bool registerchange, bool is_loc
             buf=format_standard_number(buf,false,(is_integertype(this)?0:p_driverspecific_digits),p_driverspecific_locale);
         }
     }
-    if (p_columntype==boolcolumn) buf= (s=="TRUE"?p_true:p_false);
+    if (p_columntype==boolcolumn) buf= (string2upper(s)=="TRUE"?p_true:p_false);
     if (p_driver_specific_data!=NULL)
     {
         delete[] p_driver_specific_data;
@@ -579,8 +579,8 @@ bool hk_column::is_findstring(unsigned int pos,const hk_string& searchtext,bool
     }
     else
     {
-        int a=where.find(search);
-        if (a>-1) return true;
+        hk_string::size_type a=where.find(search);
+        if (a!=hk_string::npos) return true;
     }
 
     return false;
@@ -764,7 +764,7 @@ void hk_column::save_columndefinition(ostream& s)
 }
 
 
-void hk_column::load_columndefinition(const hk_string& definition)
+void hk_column::load_columndefinition(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_column::loadstructure");
@@ -918,12 +918,14 @@ long int hk_column::asinteger(void)
 
 long int hk_column::asinteger_at(unsigned long  a)
 {
+     if (columntype()==boolcolumn)    return (driver_specific_asstring_at(a)==p_true?1:0);
      return(long int) standardstring2double(driver_specific_asstring_at(a));
 }
 
 
 long int hk_column::changed_data_asinteger(void)
 {
+     if (columntype()==boolcolumn)    return (p_new_data_asstring==p_true?1:0);
     return (long int) standardstring2double(p_new_data_asstring);
 }
 
