@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.77 $
+//$Revision: 1.82 $
 #include "hk_connection.h"
 #include "hk_database.h"
 #include "hk_datasource.h"
@@ -19,13 +19,45 @@
 #include <time.h>
 #include <termios.h>
 #include <sys/stat.h>
+#include <sys/types.h>
 #include <unistd.h>
 #include <dirent.h>
 
 password_dialogtype* hk_connection::p_passworddialog=NULL;
 newpassword_dialogtype* hk_connection::p_newpassworddialog=NULL;
 
-
+const char* sqltokens[]=
+{
+ "ABSOLUTE","ACTION","ADD","ALL","ALLOCATE","ALTER","AND","ANY",
+ "ARE","AS","ASC","ASSERTION","AT","AUTHORIZATION","AVG","BEGIN",
+ "BETWEEN","BIT","BIT_LENGTH","BOTH","BY","CASCADE","CASCADED","CASE",
+ "CAST","CATALOG","CHAR","CHARACTER","CHAR_LENGTH","CHARACTER_LENGTH","CHECK","CLOSE",
+ "COALESCE","COLLATE","COLLATION","COLUMN","COMMIT","CONNECT","CONNECTION","CONSTRAINT",
+ "CONSTRAINTS","CONTINUE","CONVERT","CORRESPONDING","COUNT","CREATE","CROSS","CURRENT",
+ "CURRENT_DATE","CURRENT_TIME","CURRENT_TIMESTAMP","CURRENT_USER","CURSOR","DATE","DAY","DEALLOCATE",
+ "DEC","DECIMAL","DECLARE","DEFAULT","DEFERRABLE","DEFERRED","DELETE","DESC",
+ "DESCRIBE","DESCRIPTOR","DIAGNOSTICS","DISCONNECT","DISTINCT","DOMAIN","DOUBLE","DROP",
+ "ELSE","END","END-EXEC","ESCAPE","EXCEPT","EXCEPTION","EXEC","EXECUTE",
+ "EXISTS","EXTERNAL","EXTRACT","FALSE","FETCH","FIRST","FLOAT","FOR",
+ "FOREIGN","FOUND","FROM","FULL","GET","GLOBAL","GO","GOTO",
+ "GRANT","GROUP","HAVING","HOUR","IDENTITY","IMMEDIATE","IN","INDICATOR",
+ "INITIALLY","INNER","INPUT","INSENSITIVE","INSERT","INT","INTEGER","INTERSECT",
+ "INTERVAL","INTO","IS","ISOLATION","JOIN","KEY","LANGUAGE","LAST",
+ "LEADING","LEFT","LEVEL","LIKE","LOCAL","LOWER","MATCH","MAX",
+ "MIN","MINUTE","MODULE","MONTH","NAMES","NATIONAL","NATURAL","NCHAR",
+ "NEXT","NO","NOT","NULL","NULLIF","NUMERIC","OCTET_LENGTH","OF",
+ "ON","ONLY","OPEN","OPTION","OR","ORDER","OUTER","OUTPUT",
+ "OVERLAPS","PAD","PARTIAL","POSITION","PRECISION","PREPARE","PRESERVE","PRIMARY",
+ "PRIOR","PRIVILEGES","PROCEDURE","PUBLIC","READ","REAL","REFERENCES","RELATIVE",
+ "RESTRICT","REVOKE","RIGHT","ROLLBACK","ROWS","SCHEMA","SCROLL","SECOND",
+ "SECTION","SELECT","SESSION","SESSION_USER","SET","SIZE","SMALLINT","SOME",
+ "SPACE","SQL","SQLCODE","SQLERROR","SQLSTATE","SUBSTRING","SUM","SYSTEMUSER",
+ "TABLE","TEMPORARY","THEN","TIME","TIMESTAMP","TIMEZONE_HOUR","TIMEZONE_MINUTE","TO",
+ "TRAILING","TRANSACTION","TRANSLATE","TRANSLATION","TRIM","TRUE","UNION","UNIQUE",
+ "UNKNOWN","UPDATE","UPPER","USAGE","USER","USING","VALUE","VALUES",
+ "VARCHAR","VARYING","VIEW","WHEN","WHENEVER","WHERE","WITH","WORK",
+ "WRITE","YEAR","ZONE"
+};
 class hk_connectionprivate
 {
 public:
@@ -58,6 +90,12 @@ hk_connection::hk_connection(hk_drivermanager* c)
     p_private->p_databasepath=p_private->p_classespath+"/";p_private->p_databasepath+=p_private->p_host.size()>0?p_private->p_host:"localhost";
     p_drivermanager=c;
     p_private->p_booleanemulation=true;
+   
+   for (unsigned int i=0;i<sizeof(sqltokens)/sizeof(const char*);++i)
+    {
+    p_sqlstatements.push_back(sqltokens[i]);
+    }
+
 
 }
 
@@ -488,6 +526,7 @@ void hk_connection::savedata(ostream& s)
     set_tagvalue(s,"TCP-PORT",(long unsigned int)p_private->p_tcp_port);
     set_tagvalue(s,"BOOLEANEMULATION",p_private->p_booleanemulation);
     set_tagvalue(s,"DATABASE",p_private->p_defaultdatabase);
+    set_tagvalue(s,"PASSWORD",p_private->p_password);
     end_mastertag(s,mt);
 
 }
@@ -501,14 +540,13 @@ void hk_connection::save_configuration(void)
     ofstream* stream= new ofstream(p_filename.c_str());
     if (stream==NULL)return;
     savedata(*stream);
-    set_tagvalue(*stream,"PASSWORD",p_private->p_password);
 
     delete stream;
     chmod(p_filename.c_str(),S_IRUSR|S_IWUSR);
 }
 
 
-void  hk_connection::loaddata(const hk_string& definition)
+void  hk_connection::loaddata(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_connection::loaddata");
@@ -532,14 +570,12 @@ void hk_connection::load_configuration(void)
     hkdebug("hk_connection::load_configuration");
 #endif
     hk_string n=p_private->p_classespath+"/driver.conf";
-
-    hk_string result;
-    ifstream ifs(n.c_str(),ios::in);
-    if (ifs)
+    if (!file_exists(n)) return;
+    xmlDocPtr doc=xmlParseFile(n.c_str());
+    xmlNodePtr result=NULL;
+    if (doc) result=xmlDocGetRootElement(doc);
+    if (doc && result)
     {
-        char c;
-        while (ifs.get(c))
-            result+=c;
         loaddata(result);
 
 	struct stat statbuf;
@@ -660,12 +696,23 @@ bool    hk_connection::database_exists(const hk_string& databasename)
 #endif
   if (server_supports(SUPPORTS_LOCAL_FILEFORMAT))
   {
+    if (server_needs(NEEDS_DIRECTORY_AS_DATABASE))
+    {
+     DIR* d=opendir(databasename.c_str());
+     if (d){
+     closedir(d);
+     return true;
+     }
+    }
+    else
+    {
     hk_url url=databasename;
     if (url.directory().size()>0)
-    {
+     {
       ifstream ifs(databasename.c_str(),ios::in);
       if (ifs )
          return true;
+     }
     }
   }
 
@@ -838,7 +885,6 @@ void hk_connection::delete_databasedirectory(const hk_string& db)
 #ifdef HK_DEBUG
     hkdebug("hk_database::delete_databasedirectory");
 #endif
-cerr <<"delete_databasedirectory "<<db<<endl;
     hk_url url=db;
     hk_string dir=(url.directory().size()>0?db:databasepath()+"/"+db);
     delete_directory(dir+"/output");
@@ -853,7 +899,6 @@ void hk_connection::delete_directory(const hk_string& d)
 #ifdef HK_DEBUG
     hkdebug("hk_database::delete_directory");
 #endif
-cerr <<"delete directory: d="<<d<<endl;
     DIR *dp;
     struct dirent *entry;
     hk_string filename;
@@ -977,3 +1022,10 @@ return true;
 }
 
 
+bool hk_connection::is_sqlstatement(const hk_string& value)
+{
+ hk_string v=string2upper(value);
+ return (find(p_sqlstatements.begin(),p_sqlstatements.end(),v)!=p_sqlstatements.end());
+}
+
+
