@@ -27,7 +27,7 @@ typedef hk_string requestdialogtype(void);
 /**
  *
  *@short  Database Driver administration
- *@version $Revision: 1.22 $
+ *@version $Revision: 1.23 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *This class allows you to handle the database drivers. You can get a new connection
@@ -77,7 +77,7 @@ class hk_drivermanager: public hk_class
     private:
         void init(bool runtime);
         void load_preferences(void);
-	void set_preferences(const hk_string& preferences);
+	void set_preferences(xmlNodePtr preferences);
 
         void    connection_remove(hk_connection* c);
         static   hk_string p_hk_classespath;
