@@ -11,15 +11,19 @@
 #ifndef HK_DSDATAVISIBLE
 #define HK_DSDATAVISIBLE
 #include "hk_dsvisible.h"
+#include <vector>
 using namespace std;
 class hk_column;
 class hk_form;
 class hk_dsdatavisiblemodeprivate;
 class hk_dsdatavisibleprivate;
+
+
+
 /**
  *
  *@short base class for visible widgets with data connection
- *@version $Revision: 1.42 $
+ *@version $Revision: 1.50 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *This is the base class for visible widgets that provides
  * access to a specific column and its data. To use visible
@@ -45,14 +49,14 @@ class hk_dsdatavisible: public hk_dsvisible
  *An object of type hk_column if it was found in the datasource
  */
         hk_column* column(void);
-        hk_string columnname(void);
+        hk_string columnname(void) const;
 /**
  * the datasource
  */
         virtual void set_datasource(hk_datasource* d);
         hk_datasource* datasource(void);
         virtual void savedata(ostream& s );
-        virtual void loaddata(const hk_string& definition);
+        virtual void loaddata(xmlNodePtr definition);
 /**
  *true if the default value will be used while inserting a new row
  */
@@ -111,6 +115,13 @@ class hk_dsdatavisible: public hk_dsvisible
 	void set_on_valuechanged_action(const hk_string&,bool registerchange=true,bool force_setting=true);
 	hk_string on_valuechanged_action(void);
         virtual bool action_on_valuechanged(void);
+    
+    virtual hk_string tag_value(int tagnumber, bool& ok);
+bool set_filtervalue(const hk_string&);
+ hk_string filtervalue(bool withcolumnnames=false) const;
+
+	static bool parsed_value(hk_string& v,hk_connection* c);
+        virtual void update_filter(void){}
     protected:
         /**
         *used from eg. hk_kdememo to allow to signal the datasource that the data has changed without writing it with hk_column::set_asstring
@@ -122,14 +133,17 @@ class hk_dsdatavisible: public hk_dsvisible
         virtual bool before_columns_deleted(void);
         virtual void widget_specific_set_column(void);
         virtual void widget_specific_numberformat(void);
+        virtual void widget_specific_set_defaultvalue(void){}
         virtual void columndata_has_changed(void){}
         virtual void before_insert_row(void);
         virtual void new_column_pointer_created(void);
 	virtual bool	presentationmode_changed(void);
         hk_column* p_column;
+        
+        hk_string p_filterreplacevalue;
+        hk_string p_filtervalueend;
 
     private:
-
         void set_column(void);
 	bool	       p_virginname;//used to find out whether to automatically set defaultvalues
         static  bool p_defaultthousandsseparator;
