@@ -26,7 +26,7 @@ void set_path(const hk_string& p,bool registerchange=true);
 void set_path(const hk_string& p,bool registerchange,bool force_setting);
 hk_string path(void) const;
 virtual void savedata(ostream& s );
-virtual void loaddata(const hk_string& definition);
+virtual void loaddata(xmlNodePtr definition);
 	virtual void set_value(const hk_string&);
 	virtual hk_string value(void);
         virtual hk_string value_at(unsigned long row);
