@@ -8,11 +8,11 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.8 $
+//$Revision: 1.9 $
 #include "hk_dslineedit.h"
 #include "hk_form.h"
 
-hk_dslineedit::hk_dslineedit(hk_form* form):hk_dsdatavisible(form)
+hk_dslineedit::hk_dslineedit(hk_form* f):hk_dsdatavisible(f)
 {
 #ifdef HK_DEBUG
     hkclassname("lineedit");
