@@ -8,5 +8,11 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.6 $
+//$Revision: 1.7 $
 #include "hk_dsrowselector.h"
+hk_dsrowselector::hk_dsrowselector(hk_form* f):hk_dsvisible(f)
+{
+p_visibletype=rowselector;
+}
+
+
