@@ -11,7 +11,7 @@
 #include "hk_dstable.h"
 
 
-hk_dstable::hk_dstable(hk_presentation* presentation):hk_dsmodevisible(presentation)
+hk_dstable::hk_dstable(hk_presentation* p):hk_dsmodevisible(p)
 {
 
 }
