@@ -21,7 +21,7 @@ class hk_dsvisibleprivate;
 /**
  *
  *@short base class for visible widgets without column data connection
- *@version $Revision: 1.37 $
+ *@version $Revision: 1.39 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *This is the base class for visible widgets which do not need access to the data,
@@ -41,7 +41,7 @@ class hk_dsvisible:public hk_visible
         hk_datasource*  datasource(void);
         virtual void savedata(ostream& s, bool savedatasource,bool saveall);
         virtual void savedata(ostream& s  );
-        virtual void loaddata(const hk_string& definition);
+        virtual void loaddata(xmlNodePtr definition);
         void    set_readonly(bool readonly);
         bool    is_readonly(void) const;
 /**
@@ -95,6 +95,7 @@ class hk_dsvisible:public hk_visible
 
 
 
+virtual hk_string tag_value(int tagnumber, bool& ok);
 
 virtual	void action_before_store_changed_data(void);
 virtual	void action_after_store_changed_data(void);
