@@ -17,7 +17,7 @@ class hk_encodingtab;
 typedef unsigned int HK_CHARSIZE;
 /**
  *@short represents a font
- *@version $Revision: 1.15 $
+ *@version $Revision: 1.16 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  */
@@ -52,7 +52,7 @@ static list<hk_string>* fontlist();
   bool text2lines(int fixedwidth,list<hk_string>* l,const hk_string& text);
 
 virtual void savedata(ostream& s );
-virtual void loaddata(const hk_string& definition);
+virtual void loaddata(xmlNodePtr definition);
 
 void set_encodingtab(hk_encodingtab* t);
 hk_encodingtab* encodingtab(void) const;
