@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.74 $
+//$Revision: 1.82 $
 #include "hk_form.h"
 #include "hk_visible.h"
 #include "hk_dsdatavisible.h"
@@ -345,6 +345,7 @@ hk_dsdate*   hk_form::new_date(void)
         set_has_changed();
         g->set_foregroundcolour(foregroundcolour());
         g->set_backgroundcolour(backgroundcolour());
+        g->set_presentationdatasource(presentationdatasource());
     }
     return g;
 
@@ -433,7 +434,7 @@ bool  hk_form::save_form(const hk_string& n,bool ask)
 }
 
 
-void hk_form::load_form(const hk_string& n)
+bool hk_form::load_form(const hk_string& n)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_form::load_form("+n+")");
@@ -441,7 +442,7 @@ void hk_form::load_form(const hk_string& n)
     if (database()==NULL)
     {
         show_warningmessage(hk_translate("Form error: No database defined!"));
-        return ;
+        return false;
 
     }
 
@@ -457,22 +458,28 @@ void hk_form::load_form(const hk_string& n)
     if (name().size()==0) if (!ask_name())
       {
        p_private->p_while_loading=false;
-       return ;
+       return false;
       }
-    hk_string res =database()->load(name(),ft_form);
+    xmlNodePtr cur =database()->xmlload(name(),ft_form);
+    if (!cur)
+    {
+     p_private->p_while_loading=false;
+     return false;
+    }
     p_private->p_loadformname=n;
-    if (res.size()==0) show_warningmessage(hk_translate("Bug: form is empty!"));
-    if ( res.find("encoding=\"UTF-8\"")<res.size() ) res=u2l(res);
-
-    loaddata(res);
+//     if (res.size()==0) show_warningmessage(hk_translate("Bug: form is empty!"));
+//     if ( res.find("encoding=\"UTF-8\"")<res.size() ) res=u2l(res);
+    loaddata(cur->xmlChildrenNode);
     p_private->p_while_loading=false;
     hk_dsmodevisible::set_mode(modebuffer);
     widget_specific_after_loadform();
+    p_private->p_while_loading=false;
     reset_has_changed();
 
 #ifdef HK_DEBUG
     hkdebug("hk_form::load_form ENDE");
 #endif
+return true;
 }
 
 bool hk_form::while_load_form(void) const
@@ -521,39 +528,27 @@ void    hk_form::savedata(ostream& s)
 }
 
 
-void    hk_form::loaddata(const hk_string& definition)
+void    hk_form::loaddata(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_form::loaddata");
 #endif
     clear_visiblelist();
-    hk_string g;
-    get_tagvalue(definition,"PRESENTATION",g,1,mastertag);
-    hk_presentation::loaddata(g);
-    if (get_tagvalue(definition,"FORMDATA",g))
-        hk_dsvisible::loaddata(g);                //delete this entry for hk_classes 1.0
+    hk_string xxx;
+    hk_presentation::loaddata(definition);
     hk_string buffer;
     hk_string buffer2;
     hk_string value;
-    long unsigned int b;
-// the following 2 lines are for compatibilty reasons to old versions <0.5
-    if (get_tagvalue(definition,"FORMDESIGNWIDTH",b))
-    {
-        unsigned int w=b;
-        long unsigned int h=0;
-        get_tagvalue(definition,"FORDESIGNHEIGHT",h);
-        set_designsize(w,h);
-    }
-// end compatibility lines
+//     long unsigned int b;
     int i=1;
-
-    while (get_tagvalue(definition,"FORMOBJECT",value,i))
-    {
-        get_tagvalue(value,"VISIBLETYPE",buffer2);
+    xmlNodePtr node;
+    while ((node=get_tagvalue(definition,"FORMOBJECT",value,i)))
+    {   
+        get_tagvalue(node,"VISIBLETYPE",buffer2);
         hk_visible* vis=new_object(buffer2);
         if (vis!=NULL)
         {
-            vis->loaddata(value);
+            vis->loaddata(node);
             register_object(vis);
         }
         i++;
@@ -570,6 +565,7 @@ void    hk_form::loaddata(const hk_string& definition)
 }
 
 
+
 hk_visible* hk_form::new_object(const hk_string& newname)
 {
     if (newname=="BUTTON") return new_button();
@@ -700,6 +696,22 @@ bool    hk_form::set_mode(enum_mode s)
         }
     if (s==viewmode)
           *p_viewdata=*p_designdata;
+    
+    
+    if (s==viewmode)
+     {
+        it=p_private->p_visibles.begin();
+	while (it!=p_private->p_visibles.end())
+        {
+	    (*it)->before_presentationmode_changed();
+	    ++it;
+        }
+      }
+    
+    
+    
+    
+    
     bool res=hk_presentation::set_mode(s);
     it=p_private->p_visibles.begin();
     if (s==viewmode)
@@ -961,3 +973,65 @@ bool hk_form::show_asdialog(hk_form*)
 return false;
 }
 
+hk_string  hk_form::form2html(enum_include)
+{
+  return "";
+}
+
+bool hk_form::set_formbasedfilter(void)
+{
+
+list<hk_datasource*>::iterator it=datasources()->begin();
+while (it!=datasources()->end())
+{
+  (*it)->set_temporaryfilter("");
+  ++it;
+}
+bool result=false;
+list<hk_visible*>::iterator vit=p_private->p_visibles.begin();
+while (vit!=p_private->p_visibles.end())
+{
+  hk_dsdatavisible* ds=dynamic_cast<hk_dsdatavisible*>(*vit);
+  if (ds)
+  {  
+    ds->update_filter();
+    hk_string f=ds->filtervalue(true);
+    if (f.size()>0 && ds->columnname().size()>0 && ds->datasource())
+    {
+      hk_string tmp=ds->datasource()->temporaryfilter();
+      if (tmp.size()>0) tmp+=" AND ";
+      ds->datasource()->set_temporaryfilter(tmp+"("+f+")");
+      result=true;
+    }
+  }
+  else
+  {
+   hk_dsgrid* g=dynamic_cast<hk_dsgrid*>(*vit);
+   if (g)
+    {
+     for(unsigned int count=0;count<g->columnscount();count++)
+      {
+        hk_dsgridcolumn* col=g->gridcolumn(count);
+        if (col)
+        {
+          
+          col->update_filter();
+          hk_string f=col->filtervalue(true);
+          if (f.size()>0 && col->columnname().size()>0 && col->datasource())
+          {
+             hk_string tmp=col->datasource()->temporaryfilter();
+             if (tmp.size()>0) tmp+=" AND ";
+             col->datasource()->set_temporaryfilter(tmp+"("+f+")");
+             result=true;
+          }
+        }
+      }
+    
+    }
+   }
+  ++vit;
+}
+return result;
+
+}
+
