@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.43 $
+//$Revision: 1.52 $
 #include "hk_importcsv.h"
 #include "hk_database.h"
 #include "hk_column.h"
@@ -22,11 +22,11 @@
 hk_importcsv::hk_importcsv(void):hk_dsvisible()
 {
 #ifdef HK_DEBUG
-//wanna_debug(true);
+// wanna_debug(true);
     hkclassname("import");
     hkdebug("hk_importcsv::constructor");
 #endif
-    p_textdelimiter="";
+    p_textdelimiter="\"";
     p_rowdelimiter="\n";
     p_betweenfields=",";
     p_filestream=NULL;
@@ -79,6 +79,8 @@ bool hk_importcsv::execute(enum_interaction enuminteractive)
 
         return false;
     }
+    bool blockbuffer=datasource()->blockvisiblesignals();
+    datasource()->set_blockvisiblesignals(true);
     hk_string sbuffer;
     int i=1;
     set_columns();
@@ -91,6 +93,8 @@ bool hk_importcsv::execute(enum_interaction enuminteractive)
     unsigned long maxsize=p_filestream->tellg();
     unsigned long r=0;
     p_filestream->seekg(spos);
+    int rowpos=1;
+    hk_string errors;
     while (!p_filestream->eof()&&!p_cancelimport)
     {
      if (p_progressdialog)
@@ -132,16 +136,30 @@ bool hk_importcsv::execute(enum_interaction enuminteractive)
         }
 
         i++;
-        datasource()->store_changed_data();
-        p_cancelimport=!widget_specific_after_new_row();
+        bool storeresult=datasource()->store_changed_data();
+        if (!storeresult)
+        { 
+        hk_string rown=format_number(rowpos,false,0);
+        hk_string msg=hk_translate(replace_all("%2",replace_all("%1","Could not import row number %1\nValue:'%2'\n\nCancel import?",rown),sbuffer));
+        errors+=rown+"\n";
+          p_cancelimport=show_yesnodialog(msg,true);
+          datasource()->set_ignore_changed_data();
+        }
+        if (!p_cancelimport)
+          p_cancelimport=!widget_specific_after_new_row();
+    ++rowpos;
     }
 #ifdef HK_DEBUG
     hkdebug("hk_importcsv::execute while ENDE");
 #endif
-
+datasource()->set_blockvisiblesignals(blockbuffer);
     reset();
-
+    if (p_cancelimport) return false;
+    else
+    {
+    if (errors.size()>0) show_warningmessage(hk_translate("Could not import the following rows:\n")+errors);
     return true;
+    }
 }
 
 
@@ -165,8 +183,8 @@ void hk_importcsv::get_line(ifstream&s ,hk_string& b)
         if (!inbrackets) noreturn=false;
       }
 
-     if (noreturn)   b=b+c;
      if (r==0) noreturn=false;
+     if (noreturn)   b=b+c;
 
 
    }
@@ -276,6 +294,9 @@ bool hk_importcsv::initialize_table(enum_interaction e)
             else col->set_size(255);
             if (col->columntype()==hk_column::integercolumn)
                (*colit).currentvalue=localestring2int((*it));
+            col->set_dateformat(p_dateformat);
+            col->set_datetimeformat(p_datetimeformat);
+            col->set_timeformat(p_timeformat);
             (*colit).col=col;
 #ifdef HK_DEBUG
             hkdebug("initialize_table ++");
@@ -356,7 +377,7 @@ bool hk_importcsv::initialize_table(enum_interaction e)
         while (colit!=p_columnlist.end())
         {
 	    if ((*colit).col->columntype()==hk_column::integercolumn&&(*colit).currentvalue>0&&!has_autoinc
-	    && i>5)
+	    && i>2)
 	    {
 	       (*colit).col->set_columntype(hk_column::auto_inccolumn);
 	       has_autoinc=true;
@@ -473,15 +494,15 @@ vector<hk_string>* hk_importcsv::create_valuelist( hk_string& row)
 {
 #ifdef HK_DEBUG
 //wanna_debug(true);
-    hkdebug("hk_importcsv::create_valuelist");
+    hkdebug("hk_importcsv::create_valuelist #"+row+"#");
 #endif
     hk_string::size_type returnkey = row.find('\r');
     row.append("\n");
     hk_string delimiters=" ";
-    if (returnkey<=row.size())  row.replace(returnkey,1,"");
+    if (returnkey!=hk_string::npos)  row.replace(returnkey,1,"");
 
     p_valuelist.erase(p_valuelist.begin(),p_valuelist.end());
-    if(row.size()<=p_textdelimiter.size()*2+p_betweenfields.size())
+    if(row.size()<2)
     {
 #ifdef HK_DEBUG
         hkdebug("hk_importcsv::create_valuelist return am Beginn der whileschleife");
@@ -506,7 +527,7 @@ vector<hk_string>* hk_importcsv::create_valuelist( hk_string& row)
         S_NORMAL_FIELD
     } state=S_START;
 //cout <<"SUCHSTRING: "<<row<<endl;
-    while (offset<=row.size())
+    while (offset<row.size())
     {
         hk_string xc(1,row[offset]);               //row[offset];
         ++offset;
@@ -526,7 +547,7 @@ vector<hk_string>* hk_importcsv::create_valuelist( hk_string& row)
                 }
                  else
                 {
-                    field += xc;
+                    field = xc;
                     state = S_NORMAL_FIELD; //cout <<"S_STARTED MAYBE_NORMAL";
                 }
                 break;
@@ -596,6 +617,7 @@ vector<hk_string>* hk_importcsv::create_valuelist( hk_string& row)
                 }
         }
     }
+    if (state!=S_START)p_valuelist.push_back(field);
 #ifdef HK_DEBUG
   if (wanna_debug())
   {
@@ -653,6 +675,13 @@ void hk_importcsv::set_columns(void)
         (*it).col=datasource()->column_by_name((*it).colname);
 //cout <<"Suche nach Column: " << (*it).colname<<" "<< (!(*it).col?"nicht ":"")<<"erfolgreich"<<endl;
 	if (!(*it).col) result+=(*it).colname+"\n";
+	else
+	{
+	    (*it).col->set_dateformat(p_dateformat);
+            (*it).col->set_datetimeformat(p_datetimeformat);
+            (*it).col->set_timeformat(p_timeformat);
+
+	}
         it++;
     }
    if (result.size()>0)
@@ -730,7 +759,8 @@ hk_column::enum_columntype hk_importcsv::interpret_columntype(hk_string& field)
     dt.set_datetimeformat(p_datetimeformat);
     dt.set_dateformat(p_dateformat);
     dt.set_timeformat(p_timeformat);
-   if (field=="TRUE"||field=="FALSE")
+    hk_string uf=string2upper(field);
+   if (uf=="TRUE"||uf=="FALSE")
    {
 #ifdef HK_DEBUG
     hkdebug("interpreted datatype: boolcolumn");
