@@ -17,7 +17,7 @@ class hk_labelmodeprivate;
 /**
  *
  *@short  base class for labels in forms
- *@version $Revision: 1.10 $
+ *@version $Revision: 1.11 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *base class for labels in forms
@@ -85,7 +85,7 @@ class hk_label:public hk_visible
 protected:
 	virtual bool	presentationmode_changed(void);
         virtual void savedata(ostream& s );
-        virtual void loaddata(const hk_string& definition);
+        virtual void loaddata(xmlNodePtr definition);
 	virtual void widget_specific_topline_changed(void){}
 	virtual void widget_specific_bottomline_changed(void){}
 	virtual void widget_specific_leftline_changed(void){}
