@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-// $Revision: 1.124 $
+// $Revision: 1.130 $
 #include "hk_report.h"
 #include "hk_reportsection.h"
 #include "hk_reportsectionpair.h"
@@ -223,6 +223,7 @@ void hk_report::setup_reportbasics(void)
         add_recodetype("Html",&recode_html);
         add_recodetype("UTF8",&recode_utf8);*/
         add_fullpagereplacefunctiontype("Postscript",&fullpagereplace_postscript);
+        add_fullpagereplacefunctiontype("ExcelXML",&fullpagereplace_excelxml);
         add_fullpagereplacefunctiontype("None",NULL);
     }
 
@@ -423,13 +424,13 @@ if (m==viewmode && while_executing())
   return true;
 hk_presentation::set_mode(m);
 
+    presentationmode_changed();
      if(m== viewmode)
      {
-       action_on_open();
+//        action_on_open();
        result= internal_execute();
      }
     vector<hk_reportsectionpair*>::iterator sit=p_sectionpairs.begin();
-    presentationmode_changed();
     while (sit!=p_sectionpairs.end())
     {
     if ((*sit)->headersection())(*sit)->headersection()->presentationmode_changed();
@@ -512,11 +513,11 @@ bool hk_report::internal_execute(void)
 	       st="\""+t+"\".\""+st+"\"";
 	       }
 	       else
-	       st=datasource()->fieldorigin(st);
+	       st=datasource()->totalfieldorigin(st);
 	    }
 	    else st="\""+st+"\"";
             if (st.size()>0 &&!(*sit)->ascending_order()) st+=" DESC";
-            if (sort.find(st)>sort.size())
+            if (sort.find(st)==hk_string::npos)
             {
                 if (sort.size()>0)sort+=" , ";
 
@@ -585,8 +586,12 @@ bool hk_report::internal_execute(void)
     do
     {
 //print header sections
+     bool stop=false;
      if (p_private->p_progressdialog)
-        p_private->p_cancelreport=p_private->p_progressdialog(p_private->p_rowposition,datasource()->max_rows(),hk_translate("Creating output ..."));
+        {
+        stop= p_private->p_progressdialog(p_private->p_rowposition,datasource()->max_rows(), hk_translate("Creating output ..."));
+        }
+        if (stop)p_private->p_cancelreport=true;
         if (p_private->p_cancelreport) stop_execution();
         vector<hk_reportsectionpair*>::iterator it=p_sectionpairs.begin();
         int p=0;
@@ -976,6 +981,7 @@ void hk_report::rowcount(unsigned long c)
 #ifdef HK_DEBUG
     hkdebug("hk_report::rowcount");
 #endif
+   //cerr <<"rowcount:"<< c <<" counter:" <<p_private->p_rowcounter<<" periodic:"<<p_private->p_includeperiodic;
     if (p_private->p_masterreport!=NULL)
     {
         p_private->p_masterreport->rowcount(c);
@@ -983,18 +989,19 @@ void hk_report::rowcount(unsigned long c)
     }
     p_private->p_rowcounter+=c;
     if ((p_private->p_includeperiodic>0)&&(p_private->p_rowcounter>(signed)p_private->p_includeperiodic))
-    {
+    { //cerr <<"newpage "<<endl<<endl;
         *outputstream()<<p_private->p_includeperiodicstring;
-        p_private->p_rowcounter=c;
         if (p_private->p_newpage_on_periodic)
         {
             if (!p_private->p_cleanpage)
                new_page();
             else p_private->p_cleanpage=false;
         }
+        p_private->p_rowcounter=c;
+        //cerr <<"neuer rowcounter="<<p_private->p_rowcounter<<endl;
     }
     else p_private->p_cleanpage=false;
-
+ //cerr <<endl;
 }
 
 
@@ -1424,15 +1431,15 @@ bool hk_report::load_report(const hk_string& n)
     				 p_private->p_while_load_report=false;
 				 return false;
     				}
-    hk_string res= database()->load(name(),ft_report);
+    xmlNodePtr res= database()->xmlload(name(),ft_report);
     p_private->p_loadreportname=n;
-    if (res.size()==0)
+    if (!res)
     {
         show_warningmessage(hk_translate("No such report!"));
             p_private->p_while_load_report=false;
         return false;
     }
-    if ( res.find("encoding=\"UTF-8\"")<res.size() ) res=u2l(res);
+//     if ( res.find("encoding=\"UTF-8\"")<res.size() ) res=u2l(res);
     loaddata(res);
     hk_dsmodevisible::set_mode(modebuffer);
     widget_specific_after_loadreport();
@@ -1455,33 +1462,32 @@ bool hk_report::while_loading(void)
   return while_load_report();
 }
 
-void  hk_report::loaddata(const hk_string& definition)
+void  hk_report::loaddata(xmlNodePtr definition)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_report::loaddata");
 #endif
 
-    hk_string sbuffer;
+    xmlNodePtr sbuffer;
     long unsigned int ibuffer;
     bool bbuffer;
-
-    get_tagvalue(definition,"PRESENTATION",sbuffer,1,mastertag);
+    hk_string xxx;
+    sbuffer=get_tagvalue(definition,"PRESENTATION",xxx,1,mastertag);
     hk_presentation::loaddata(sbuffer);
 
     hk_string reptype;
 
     get_tagvalue(definition,"REPORTTYPE",reptype);
-    hk_string r;
-    get_tagvalue(definition,"REPORTDEFINITION",r);
+    xmlNodePtr r=get_tagvalue(definition,"REPORTDEFINITION");
 //	hk_dsvisible::loaddata(r);
     if (get_tagvalue(r,"DEFAULTPRECISION",ibuffer))p_private->p_default_precision=ibuffer;
     if (get_tagvalue(r,"DEFAULTUSETHOUSANDSSEPARATOR",bbuffer))p_private->p_default_use_thousandsseparator=bbuffer;
 
-    if (get_tagvalue(r,"FILENAME",sbuffer))set_filename(sbuffer);
+    if (get_tagvalue(r,"FILENAME",xxx))set_filename(xxx);
     if (get_tagvalue(r,"STARTPAGENUMBER",ibuffer))p_private->p_startpagenumber=ibuffer;
     if (get_tagvalue(r,"MULTIPLEFILES",bbuffer))p_multiplefiles=bbuffer;
     get_tagvalue(r,"PRINTFULLPAGESONLY",p_private->p_print_full_pages_only);
-    if (get_tagvalue(r,"PAGENAME",sbuffer))p_private->p_pagename=sbuffer;
+    if (get_tagvalue(r,"PAGENAME",xxx))p_private->p_pagename=xxx;
     if (get_tagvalue(r,"BORDERLEFT",ibuffer))p_private->p_borderleft=ibuffer;
     if (get_tagvalue(r,"BORDERRIGHT",ibuffer)) p_private->p_borderright=ibuffer;
     if (get_tagvalue(r,"BORDERTOP",ibuffer)) p_private->p_bordertop=ibuffer;
@@ -1493,59 +1499,59 @@ void  hk_report::loaddata(const hk_string& definition)
     if (get_tagvalue(r,"LORULINE",bbuffer))p_private->p_loru=bbuffer;
     if (get_tagvalue(r,"LUROLINE",bbuffer))p_private->p_luro=bbuffer;
     get_tagvalue(r,"ONPRINTNEWPAGE_ACTION",p_private->p_on_new_page_action);
-    if (get_tagvalue(r,"ORIENTATION",sbuffer))
+    if (get_tagvalue(r,"ORIENTATION",xxx))
     {
-        if (sbuffer=="LANDSCAPE") set_orientation(hk_report::landscape);
+        if (xxx=="LANDSCAPE") set_orientation(hk_report::landscape);
         else        set_orientation(hk_report::portrait);
     }
 
     pageformattype p_formattyp;
-    get_tagvalue(r,"PAGEFORMAT",sbuffer);
-    if(sbuffer=="A0") p_formattyp=hk_report::A0;else
-        if(sbuffer=="A1") p_formattyp=hk_report::A1;else
-            if(sbuffer=="A2") p_formattyp=hk_report::A2;else
-                if(sbuffer=="A3") p_formattyp=hk_report::A3;else
-                    if(sbuffer=="A4") p_formattyp=hk_report::A4;else
-                        if(sbuffer=="A5") p_formattyp=hk_report::A5;else
-                            if(sbuffer=="A6") p_formattyp=hk_report::A6;else
-                                if(sbuffer=="A7") p_formattyp=hk_report::A7;else
-                                    if(sbuffer=="A8") p_formattyp=hk_report::A8;else
-                                        if(sbuffer=="A9") p_formattyp=hk_report::A9;else
-                                            if(sbuffer=="A10") p_formattyp=hk_report::A10;else
-                                                if(sbuffer=="LETTER") p_formattyp=hk_report::letter;else
-                                                    if(sbuffer=="LEGAL") p_formattyp=hk_report::legal;else
-                                                        if(sbuffer=="EXECUTIVE") p_formattyp=hk_report::executive;else
-                                                            if(sbuffer=="TABLOID") p_formattyp=hk_report::tabloid;else
+    get_tagvalue(r,"PAGEFORMAT",xxx);
+    if(xxx=="A0") p_formattyp=hk_report::A0;else
+        if(xxx=="A1") p_formattyp=hk_report::A1;else
+            if(xxx=="A2") p_formattyp=hk_report::A2;else
+                if(xxx=="A3") p_formattyp=hk_report::A3;else
+                    if(xxx=="A4") p_formattyp=hk_report::A4;else
+                        if(xxx=="A5") p_formattyp=hk_report::A5;else
+                            if(xxx=="A6") p_formattyp=hk_report::A6;else
+                                if(xxx=="A7") p_formattyp=hk_report::A7;else
+                                    if(xxx=="A8") p_formattyp=hk_report::A8;else
+                                        if(xxx=="A9") p_formattyp=hk_report::A9;else
+                                            if(xxx=="A10") p_formattyp=hk_report::A10;else
+                                                if(xxx=="LETTER") p_formattyp=hk_report::letter;else
+                                                    if(xxx=="LEGAL") p_formattyp=hk_report::legal;else
+                                                        if(xxx=="EXECUTIVE") p_formattyp=hk_report::executive;else
+                                                            if(xxx=="TABLOID") p_formattyp=hk_report::tabloid;else
                                                                 p_formattyp=hk_report::userdefined;
     set_pageformat(p_formattyp);
-
-    if (get_tagvalue(r,"PAGEHEADSECTION",sbuffer,1,mastertag))
+     xmlNodePtr s=NULL;
+    if ((s=get_tagvalue(r,"PAGEHEADSECTION",xxx,1,mastertag)))
     {
-        if (p_private->p_pageheader!=NULL) p_private->p_pageheader->loaddata(sbuffer);
+        if (p_private->p_pageheader!=NULL) p_private->p_pageheader->loaddata(s);
     }
-    if (get_tagvalue(r,"PAGEFOOTSECTION",sbuffer,1,mastertag))
+    if ((s=get_tagvalue(r,"PAGEFOOTSECTION",xxx,1,mastertag)))
     {
-        if (p_private->p_pagefooter!=NULL) p_private->p_pagefooter->loaddata(sbuffer);
+        if (p_private->p_pagefooter!=NULL) p_private->p_pagefooter->loaddata(s);
     }
-    if (get_tagvalue(r,"REPORTHEADERSECTION",sbuffer,1,mastertag))
+    if ((s=get_tagvalue(r,"REPORTHEADERSECTION",xxx,1,mastertag)))
     {
-        if (p_private->p_reportheader!=NULL) p_private->p_reportheader->loaddata(sbuffer);
+        if (p_private->p_reportheader!=NULL) p_private->p_reportheader->loaddata(s);
     }
-    if (get_tagvalue(r,"REPORTFOOTERSECTION",sbuffer,1,mastertag))
+    if ((s=get_tagvalue(r,"REPORTFOOTERSECTION",xxx,1,mastertag)))
     {
-        if (p_private->p_reportfooter!=NULL) p_private->p_reportfooter->loaddata(sbuffer);
+        if (p_private->p_reportfooter!=NULL) p_private->p_reportfooter->loaddata(s);
     }
 
-    if (get_tagvalue(r,"REPORTDATASECTION",sbuffer,1,mastertag))
+    if ((s=get_tagvalue(r,"REPORTDATASECTION",xxx,1,mastertag)))
     {
-        if (p_private->p_datasection!=NULL) p_private->p_datasection->loaddata(sbuffer);
+        if (p_private->p_datasection!=NULL) p_private->p_datasection->loaddata(s);
     }
 
-    hk_string sectionbuffer;
-    if (get_tagvalue(definition,"SECTIONPAIRS",sectionbuffer))
+    xmlNodePtr sectionbuffer;
+    if ((sectionbuffer=get_tagvalue(definition,"SECTIONPAIRS")))
     {
         int counter=1;
-        while (get_tagvalue(sectionbuffer,"HK_REPORTSECTIONPAIR",sbuffer,counter,mastertag))
+        while ((sbuffer=get_tagvalue(sectionbuffer,"HK_REPORTSECTIONPAIR",xxx,counter,mastertag)))
         {
             hk_reportsectionpair* newsection=new_sectionpair();
             if (newsection!=NULL)
@@ -1571,14 +1577,14 @@ void  hk_report::loaddata(const hk_string& definition)
         get_tagvalue(r,"DEFAULTBEFORECOLUMN",p_default_beforedata);
         get_tagvalue(r,"DEFAULTAFTERCOLUMN",p_default_afterdata);
         get_tagvalue(r,"DEFAULTDATACONFIGUREFUNCTION",p_default_dataconfigurefunction);
-        if (get_tagvalue(r,"RECODEFUNCTION",sbuffer))
-            set_recodefunction(sbuffer);
-        if (get_tagvalue(r,"FULLPAGEREPLACEFUNCTION",sbuffer))
-            set_fullpagereplacefunction(sbuffer);
+        if (get_tagvalue(r,"RECODEFUNCTION",xxx))
+            set_recodefunction(xxx);
+        if (get_tagvalue(r,"FULLPAGEREPLACEFUNCTION",xxx))
+            set_fullpagereplacefunction(xxx);
 
         get_tagvalue(r,"DEFAULTSECTIONCOUNTFUNCTION",p_private->p_defaultsectioncountfunction);
-        if (get_tagvalue(r,"REPORTCONFIGUREFUNCTION",sbuffer))
-            set_reportconfigurefunction(sbuffer,false);
+        if (get_tagvalue(r,"REPORTCONFIGUREFUNCTION",xxx))
+            set_reportconfigurefunction(xxx,false);
         get_tagvalue(r,"PRINTFULLPAGEONLY",p_private->p_print_full_pages_only);
 }
 
