@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.77 $
+//$Revision: 1.80 $
 #include "hk_reportdata.h"
 #include "hk_reportsection.h"
 #include "hk_report.h"
@@ -123,6 +123,7 @@ list<hk_string> hk_reportdata::p_datareplacefunctionlist;
 hk_reportdata::hk_reportdata(hk_reportsection* s):hk_dsdatavisible(s->report())
 {
 #ifdef HK_DEBUG
+// wanna_debug(true);
     hkdebug("hk_reportdata::hk_reportdata");
 #endif
     p_viewdata=new hk_reportdatamodeprivate;
@@ -146,6 +147,7 @@ hk_reportdata::hk_reportdata(hk_reportsection* s):hk_dsdatavisible(s->report())
     if (p_reportdataconfigurefunctions.size()==0)
     {
         add_configurefunctiontype("Postscript",&configure_postscriptdata);
+        add_configurefunctiontype("ExcelXML",&configure_excelxmldata);
         add_configurefunctiontype("None",NULL);
     }
 
@@ -162,6 +164,7 @@ hk_reportdata::hk_reportdata(hk_reportsection* s):hk_dsdatavisible(s->report())
     {
         add_datareplacefunctiontype("FILECHARACTERSET",&encodefilecharsetfunction);
         add_datareplacefunctiontype("Postscript",&replacepsdatafunction);
+        add_datareplacefunctiontype("ExcelXML",&replaceexcelxmldatafunction);
         add_datareplacefunctiontype("None",NULL);
     }
     set_replacefunction("None",false);
@@ -292,11 +295,14 @@ hk_string hk_reportdata::actual_string(void)
     }
     hk_string r=replace(p_viewdata->p_beforedata);
    recodefunctiontype* rf=(p_report?p_report->recodefunction():NULL);
+   
 
     r+=rf?rf(displayvalue,p_report):displayvalue;
     r+=replace(p_viewdata->p_afterdata);
+   if (p_private->p_replacefunction!=NULL) r=p_private->p_replacefunction(this,r);
     if (p_private->p_datacountfunction!=NULL)set_counts_as(p_private->p_datacountfunction(this));
-    p_report->rowcount(counts_as());
+   if (p_report->page_header()!=p_section &&p_report->page_footer()!=p_section  )
+       p_report->rowcount(counts_as());
     p_private->p_first_print=false;
     ++p_private->p_pages;
     return  r;
@@ -459,14 +465,14 @@ bool hk_reportdata::runningcount(void)
 void hk_reportdata::set_replacefunction(const hk_string& f,bool registerchange)
 {
 #ifdef HK_DEBUG
-    hkdebug("hk_reportdata::set_replacefunction");
+    hkdebug("hk_reportdata::set_replacefunction:"+f);
 #endif
     if (f==p_private->p_replacefunctionstring)return;
     datareplacelisttype::iterator it=p_datareplacefunctions.find(f);
     if (it==p_datareplacefunctions.end())
     {
 
-        show_warningmessage(hk_translate("replacefunction not found"));
+        show_warningmessage(replace_all("%1",hk_translate("replacefunction '%1' not found"),f));
         p_private->p_replacefunction=NULL;
         p_private->p_replacefunctionstring="None";
         return;
@@ -476,6 +482,9 @@ void hk_reportdata::set_replacefunction(const hk_string& f,bool registerchange)
     p_private->p_replacefunction=c;
     p_private->p_replacefunctionstring=f;
     has_changed(registerchange);
+#ifdef HK_DEBUG
+    hkdebug("hk_reportdata::set_replacefunction:"+f+" found and set");
+#endif
 }
 
 
@@ -768,7 +777,7 @@ void  hk_reportdata::savedata(ostream& s,bool userdefined)
 }
 
 
-void  hk_reportdata::loaddata(const hk_string& definition,bool userdefined)
+void  hk_reportdata::loaddata(xmlNodePtr definition,bool userdefined)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_reportdata::loaddata");
@@ -817,7 +826,7 @@ void  hk_reportdata::loaddata(const hk_string& definition,bool userdefined)
 void    hk_reportdata::set_configurefunction(const hk_string& f,bool registerchange)
 {
 #ifdef HK_DEBUG
-    hkdebug("hk_reportdata::set_configurefunction");
+    hkdebug("hk_reportdata::set_configurefunction:"+f);
 #endif
 
     if (f==p_private->p_dataconfigurefunctionstring)return;
@@ -1073,7 +1082,6 @@ hk_string hk_reportdata::tag_value(int tagnumber, bool& ok)
    int w=0;
 
     hk_string result;
-//    if (p_private->p_replacefunction!=NULL) p_localbuffer=p_private->p_replacefunction(this,p_localbuffer);
 
       if (tagnumber==p_private->tag_XPOS)
     {
