@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.70 $
+//$Revision: 1.72 $
 #include "hk_reportsection.h"
 #include "hk_reportsectionpair.h"
 #include "hk_report.h"
@@ -493,6 +493,7 @@ if (!p_printsection) return true;
 bool hk_reportsection::is_fully_printed(void)
 {
         if (!p_printsection) return true;
+        if (p_report->execution_stopped()) return true;
         vector<hk_reportdata*>::iterator vit=p_data.begin();
         while (vit!=p_data.end())
         {
@@ -766,7 +767,7 @@ void  hk_reportsection::savedata(ostream& s,bool userdefined)
 }
 
 
-void  hk_reportsection::loaddata(const hk_string& definition,bool userdefined)
+void  hk_reportsection::loaddata(xmlNodePtr definition,bool userdefined)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_reportsection::loaddata");
@@ -792,10 +793,10 @@ void  hk_reportsection::loaddata(const hk_string& definition,bool userdefined)
 
     int i=1;
     clear_depending_fields();
-    hk_string dpf;
+    xmlNodePtr dpf;
     hk_string thisfield;
     hk_string subfield;
-    if (get_tagvalue(definition,"REPORTDEPENDINGFIELDS",dpf))
+    if ((dpf=get_tagvalue(definition,"REPORTDEPENDINGFIELDS")))
     {
         while (get_tagvalue(dpf,"THISREPORTFIELD",thisfield,i))
         {
@@ -805,16 +806,17 @@ void  hk_reportsection::loaddata(const hk_string& definition,bool userdefined)
         }
     }
 
-    hk_string databuffer;
-    if (get_tagvalue(definition,"SECTIONDATA",databuffer))
+    xmlNodePtr databuffer;
+    if ((databuffer=get_tagvalue(definition,"SECTIONDATA")))
     {
         int counter=1;
-        while (get_tagvalue(databuffer,"HK_REPORTDATA",sbuffer,counter,mastertag))
+        xmlNodePtr node;
+        while ((node=get_tagvalue(databuffer,"HK_REPORTDATA",sbuffer,counter,mastertag)))
         {
             hk_reportdata* newdata=new_data();
             if (newdata!=NULL)
             {
-                newdata->loaddata(sbuffer);
+                newdata->loaddata(node);
             }
 
             counter++;
