@@ -191,19 +191,20 @@ void  hk_reportsectionpair::savedata(ostream& s,bool userdefined)
 }
 
 
-void  hk_reportsectionpair::loaddata(const hk_string& definition,bool userdefined)
+void  hk_reportsectionpair::loaddata(xmlNodePtr definition,bool userdefined)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_reportsectionpair::loaddata");
 #endif
+    xmlNodePtr node;
     hk_string sbuffer;
-    if (get_tagvalue(definition,"HEADERSECTION",sbuffer,1,mastertag))
+    if ((node=get_tagvalue(definition,"HEADERSECTION",sbuffer,1,mastertag)))
     {
-        if (p_header!=NULL) p_header->loaddata(sbuffer,userdefined);
+        if (p_header!=NULL) p_header->loaddata(node,userdefined);
     }
-    if (get_tagvalue(definition,"FOOTERSECTION",sbuffer,1,mastertag))
+    if ((node=get_tagvalue(definition,"FOOTERSECTION",sbuffer,1,mastertag)))
     {
-        if (p_footer!=NULL) p_footer->loaddata(sbuffer,userdefined);
+        if (p_footer!=NULL) p_footer->loaddata(node,userdefined);
     }
     if (get_tagvalue(definition,"PAIRCOLUMNNAME",sbuffer))set_columnname(sbuffer);
     get_tagvalue(definition,"ASCENDINGORDER",p_ascending);
