@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.78 $
+//$Revision: 1.80 $
 #include "hk_reportutils.h"
 #include "hk_reportsectionpair.h"
 #include "hk_datasource.h"
@@ -95,7 +95,7 @@ void hk_reporthtml::configure_table(void)
     if (p_withheader)
     {
         buffer="<TH ";
-        buffer+=p_thtag+">%FIELDNAME%</TH>";
+        buffer+=p_thtag+">%COLUMNNAME%</TH>";
         p_tableheadersection->set_sectionbegin(trtag);
         p_tableheadersection->set_sectionend(trendtag);
 
@@ -446,6 +446,7 @@ unsigned long recount_postscript(hk_reportsection* s)
 
 hk_string replacepsdatafunction(hk_reportdata* rd,const hk_string& value)
 {
+return value;
 if (!rd) return value; 
 hk_string result=replace_all("%BASEFONT%",value,basefont(rd->font().psfontname(),rd->report()));
 return result;
@@ -786,7 +787,7 @@ void hk_reportcsv::configure_page(void)
     if (p_withheader)
     {
 
-        hk_string h=p_delimiter+"%FIELDNAME%";
+        hk_string h=p_delimiter+"%COLUMNNAME%";
         h+=p_delimiter;
         page_header()->set_default_reportdata(h);
         page_header()->set_betweendata(p_between);
@@ -837,7 +838,7 @@ void    hk_reportcsv::widget_specific_after_execute(void)
 //     {
 //
 //         hk_reportsectionpair* header=e->new_sectionpair();
-//         hk_string h=delimiter+"%FIELDNAME%";
+//         hk_string h=delimiter+"%COLUMNNAME%";
 //         h+=delimiter;
 //         header->headersection()->set_default_reportdata(h);
 //         header->headersection()->set_betweendata(between);
@@ -903,6 +904,7 @@ hk_reportxml::hk_reportxml(void):hk_report()
     set_maindocumenttag("table");
     set_rowtag("row");
     set_includetableschema(false);
+    p_excelxml=false;
     p_fieldtag=fieldname;
     configure_page();
 }
@@ -927,6 +929,16 @@ hk_reportxml::enum_fieldtag hk_reportxml::fieldname_as_attribute(void)
     return p_fieldtag;
 }
 
+void hk_reportxml::set_excelxml(bool e)
+{
+p_excelxml=e;
+configure_page();
+}
+
+bool hk_reportxml::excelxml(void)
+{
+return p_excelxml;
+}
 
 bool hk_reportxml::set_maindocumenttag(const hk_string& t)
 {
@@ -959,8 +971,21 @@ hk_string hk_reportxml::rowtag(void)
 }
 
 
+
+
 void hk_reportxml::configure_page(void)
 {
+    if (excelxml())
+    {
+      configure_excelpage();
+      
+      return;
+    }
+    ;
+   set_print_full_pages_only(false,false);
+   set_fullpagereplacefunction("None",false);
+   set_default_reportdataconfigurefunction("None",false);
+    
     hk_string header= "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n<!DOCTYPE %DT%>\n<%DT%>\n";
     header=replace_all("%DT%",header,p_maindocumenttag);
     hk_string footer=replace_all("%DT%","</%DT%>\n",p_maindocumenttag);
@@ -980,14 +1005,120 @@ void hk_reportxml::configure_page(void)
        else d->set_data("");
     }
 
-    datasection()->set_default_beforereportdata(p_fieldtag==fieldname?"   <%FIELDNAME%>":"   <field NAME=\"%FIELDNAME%\">");
-    datasection()->set_default_afterreportdata(p_fieldtag==fieldname?"</%FIELDNAME%>\n":"</field>\n");
+    datasection()->set_default_beforereportdata(p_fieldtag==fieldname?"   <%COLUMNNAME%>":"   <field NAME=\"%COLUMNNAME%\">");
+    datasection()->set_default_afterreportdata(p_fieldtag==fieldname?"</%COLUMNNAME%>\n":"</field>\n");
     datasection()->set_sectionbegin(replace_all("%RT%","  <%RT%>\n",p_rowtag));
     datasection()->set_sectionend(replace_all("%RT%","  </%RT%>\n",p_rowtag));
     datasection()->set_automatic_create_data(true);
 }
 
 
+
+void    hk_reportxml::configure_excelpage(void)
+{  
+   set_print_full_pages_only(true,false);
+   set_fullpagereplacefunction("ExcelXML",false);
+   set_default_reportdataconfigurefunction("ExcelXML",false);
+   datasection()->set_default_reportdataconfigurefunction("ExcelXML",false);
+  hk_string header="<?xml version=\"1.0\"?>\n\
+<?mso-application progid=\"Excel.Sheet\"?>\n\
+<Workbook xmlns=\"urn:schemas-microsoft-com:office:spreadsheet\"\n\
+ xmlns:o=\"urn:schemas-microsoft-com:office:office\"\n\
+ xmlns:x=\"urn:schemas-microsoft-com:office:excel\"\n\
+ xmlns:ss=\"urn:schemas-microsoft-com:office:spreadsheet\"\n\
+ xmlns:html=\"http://www.w3.org/TR/REC-html40\">\n\
+ <DocumentProperties xmlns=\"urn:schemas-microsoft-com:office:office\">\n\
+  <Author>HK_CLASSES</Author>\n\
+  <LastAuthor>HK_CLASSES</LastAuthor>\n\
+  <Created>%DATETIME%</Created>\n\
+  <LastSaved>%DATETIME%</LastSaved>\n\
+  <Version>11.6360</Version>\n\
+ </DocumentProperties>\n\
+ <ExcelWorkbook xmlns=\"urn:schemas-microsoft-com:office:excel\">\n\
+  <WindowHeight>9210</WindowHeight>\n\
+  <WindowWidth>11595</WindowWidth>\n\
+  <WindowTopX>360</WindowTopX>\n\
+  <WindowTopY>60</WindowTopY>\n\
+  <ProtectStructure>False</ProtectStructure>\n\
+  <ProtectWindows>False</ProtectWindows>\n\
+ </ExcelWorkbook>\n\
+ <Styles>\n\
+  <Style ss:ID=\"Default\" ss:Name=\"Normal\">\n\
+   <Alignment ss:Vertical=\"Bottom\"/>\n\
+   <Borders/>\n\
+   <Font/>\n\
+   <Interior/>\n\
+   <NumberFormat/>\n\
+   <Protection/>\n\
+  </Style>\n\
+ </Styles>\n<Worksheet ss:Name=\"Tabelle1\">\n\
+  <Table ss:ExpandedColumnCount=\"%COLS%\" ss:ExpandedRowCount=\"%ROWS%\" x:FullColumns=\"1\"\
+   x:FullRows=\"1\" ss:DefaultColumnWidth=\"60\">\n";
+    hk_datetime dt;
+    dt.set_now();
+    dt.set_datetimeformat("Y-M-DTh:m:sZ");
+    header=replace_all("%DATETIME%",header,dt.datetime_asstring());
+    hk_string footer="  </Table>\n\
+  <WorksheetOptions xmlns=\"urn:schemas-microsoft-com:office:excel\">\n\
+   <PageSetup>\n\
+    <Header x:Margin=\"0.4921259845\"/>\n\
+    <Footer x:Margin=\"0.4921259845\"/>\n\
+    <PageMargins x:Bottom=\"0.984251969\" x:Left=\"0.78740157499999996\"\n\
+     x:Right=\"0.78740157499999996\" x:Top=\"0.984251969\"/>\n\
+   </PageSetup>\n\
+   <Selected/>\n\
+   <Panes>\n\
+    <Pane>\n\
+     <Number>3</Number>\n\
+     <ActiveRow>0</ActiveRow>\n\
+     <ActiveCol>0</ActiveCol>\n\
+    </Pane>\n\
+   </Panes>\n\
+   <ProtectObjects>False</ProtectObjects>\n\
+   <ProtectScenarios>False</ProtectScenarios>\n\
+  </WorksheetOptions>\n\
+ </Worksheet>\n\
+</Workbook>\n";
+    hk_reportdata* d=NULL;
+    if (page_header()->datalist()->size()==0) d=page_header()->new_data();
+    else d=page_header()->data_at(0);
+    if (d!=NULL)
+    {
+        d->set_data(header);
+    }
+
+    if (page_footer()->datalist()->size()==0) d=page_footer()->new_data();
+    else d=page_footer()->data_at(0);
+    if (d!=NULL)
+    {
+       d->set_data(footer);
+    }
+
+    datasection()->set_default_beforereportdata("<Cell><Data ss:Type=\"%TYPE%\">");
+    datasection()->set_default_afterreportdata("</Data></Cell>\n");
+    datasection()->set_sectionbegin("<Row>\n");
+    datasection()->set_sectionend("</Row>\n");
+    datasection()->set_automatic_create_data(true);
+
+
+
+
+
+
+
+
+
+
+}
+
+
+
+
+
+
+
+
+
 void    hk_reportxml::widget_specific_before_execute(void)
 {
     setlocale(LC_NUMERIC,"C");
@@ -1028,3 +1159,39 @@ void hk_reportxml::widget_specific_before_last_outstream_closed(void)
 	(*outputstream())<<footer;
       }
 }
+
+
+
+hk_string  fullpagereplace_excelxml(const hk_string& where,hk_report* report)
+{
+  hk_report* r=NULL;
+  if (report->masterreport()) r=report->masterreport();
+  else r=report;
+  if (!r || !r->datasource()) return where;
+  hk_string cols=format_number(r->datasource()->columns()->size(),false,0);
+  hk_string rows=format_number(r->datasource()->max_rows(),false,0);
+  hk_string result=replace_all("%COLS%",where,cols);
+  
+  result=replace_all("%ROWS%",result,rows);
+  return result;
+}
+
+hk_string replaceexcelxmldatafunction(hk_reportdata* rd,const hk_string& value)
+{
+if (!rd) return value; 
+if (!rd->column()) return value;
+hk_string type="String";
+if (is_numerictype(rd->column())) type="Number";
+hk_string result=replace_all("%TYPE%",value,type);
+return result;
+}
+
+
+
+
+void   configure_excelxmldata(hk_reportdata* d)
+{
+    if (d==NULL) return;
+    d->set_replacefunction("ExcelXML",false);
+}
+
