@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.13 $
+//$Revision: 1.14 $
 #include "hk_firebirdtable.h"
 #include "hk_firebirddatabase.h"
 #include "hk_firebirdcolumn.h"
@@ -170,9 +170,9 @@ AND RDB$RELATION_NAME='"+name()+"' ORDER BY RDB$RELATION_FIELDS.RDB$FIELD_POSITI
         hk_string searchname=trim(fieldname->asstring());
         while ( it!=p_columns->end())
         {
-            hk_column* x=*it;
+            hk_column* xc=*it;
             ++it;
-            if (x->name()==searchname) c=x;
+            if (xc->name()==searchname) c=xc;
 
         }
   	if (c)
@@ -214,9 +214,9 @@ AND RDB$RELATION_NAME='"+name()+"' ORDER BY RDB$RELATION_FIELDS.RDB$FIELD_POSITI
         hk_string searchname=trim(column);
         while ( it!=p_columns->end())
         {
-            hk_column* x=*it;
+            hk_column* xc=*it;
             ++it;
-            if (x->name()==searchname) c=dynamic_cast<hk_firebirdcolumn*>(x);
+            if (xc->name()==searchname) c=dynamic_cast<hk_firebirdcolumn*>(xc);
 
         }
   	if (c)
@@ -267,9 +267,9 @@ AND I.RDB$INDEX_NAME=F.RDB$INDEX_NAME AND C.RDB$RELATION_NAME='"+name()+"'";
         hk_string searchname=trim(keyfield->asstring());
         while ( it!=p_columns->end())
         {
-            hk_column* x=*it;
+            hk_column* xc=*it;
             ++it;
-            if (x->name()==searchname) c=x;
+            if (xc->name()==searchname) c=xc;
 
         }
   	if (c)
@@ -595,7 +595,7 @@ hk_string  hk_firebirdtable::internal_alter_fields_arguments(void)
   //  char* m= new char[50];
   hk_string m;
     hk_string result;
-    hk_string name;
+    
     list<class_altercolumns>::iterator it=p_altercolumns.begin();
     while (it!=p_altercolumns.end())
     {
@@ -712,40 +712,40 @@ bool in_gen_id=false;
 bool get_columnname=false;
 while (offset<t.size())
 {
-	hk_string x(1,t[offset]);
+	hk_string xc(1,t[offset]);
 	switch (state)
 	{
 	case S_START:  //cerr<<"S_START"<<endl;
 			tag="";
-			if (isspace(x[0]))
+			if (isspace(xc[0]))
 				{
-					if (x=="\n")
+					if (xc=="\n")
 					{
 						++row;col=0;
 					}
 				  break;
 				}
 			else
-			if (x=="\"")
+			if (xc=="\"")
 			   {
 			     state=S_IN_DOUBLEQUOTE;
 			   }
 			else
-			if (x=="'")
+			if (xc=="'")
 			 state=S_IN_QUOTE;
 			else
-			if (x=="(" && in_gen_id)
+			if (xc=="(" && in_gen_id)
 			{
 			  state=S_IN_TAG;
 			}
 			else
 			 {
 			  state=S_IN_TAG;
-			  tag=string2upper(x);
+			  tag=string2upper(xc);
 			 }
 			break;
 	case S_IN_QUOTE://cerr<<"S_IN_QUOTE"<<endl;
-			  if (x=="'")
+			  if (xc=="'")
 			   {
  			    if (in_gen_id)
  			    {
@@ -760,7 +760,7 @@ while (offset<t.size())
 			   }
 			  else
 			  {
-			  tag+=x;
+			  tag+=xc;
 			  //cerr<<"tag=#"<<tag<<"#"<<endl;
 			  }
 
@@ -768,7 +768,7 @@ while (offset<t.size())
 
 
 	case S_IN_DOUBLEQUOTE://cerr<<"S_IN_DOUBLE_QUOTE"<<endl;
-			  if (x=="\"")
+			  if (xc=="\"")
 			   {
 			  if (column.size()>0)
 			  {
@@ -793,7 +793,7 @@ while (offset<t.size())
 			   }
 			  else
 			  {
-			  tag+=x;
+			  tag+=xc;
 			  //cerr<<"tag=#"<<tag<<"#"<<endl;
 			  }
 
@@ -802,20 +802,20 @@ while (offset<t.size())
 
 
 	case S_IN_TAG://cerr<<"S_IN_TAG"<<endl;
-			if (x=="." && string2upper(tag)=="NEW")
+			if (xc=="." && string2upper(tag)=="NEW")
 			{
 			    get_columnname=true;
 			    //cerr <<"NEW found! get_columnname=true"<<endl;
 			    state=S_START;
 			    break;
 			}
-			if (x=="(" &&string2upper(tag)=="GEN_ID")
+			if (xc=="(" &&string2upper(tag)=="GEN_ID")
 			 {
 			  	in_gen_id=true;
 			   tag="";
 			   state=S_START;
                          }
-			if (isspace(x[0])|| tag==",")
+			if (isspace(xc[0])|| tag==",")
 			 {
 			  if (get_columnname)
 			  {
@@ -842,13 +842,13 @@ while (offset<t.size())
 			 }
 			else
 			{
-			  if (in_gen_id &&x==")")
+			  if (in_gen_id &&xc==")")
 			  {
 			    generator=tag;
 			    return true;
 			  }
 			  else
-  			  if (in_gen_id &&x==",")
+  			  if (in_gen_id &&xc==",")
 			  {
 			    generator=tag;
 			    return true;
@@ -856,7 +856,7 @@ while (offset<t.size())
 
 			}
 			  {
-			  tag+=string2upper(x);
+			  tag+=string2upper(xc);
 			  //cerr<<"tag=#"<<tag<<"#"<<endl;
 			  }
 			break;
