@@ -19,7 +19,8 @@ hk_mdbcolumn::hk_mdbcolumn(hk_mdbdatasource* ds, const hk_string& tTRUE,const hk
 //wanna_debug(true);
     hkdebug("hk_mdbcolumn::constructor");
 #endif
-    p_driverspecific_timestampformat="YMDhms";
+//     p_driverspecific_timestampformat="YMDhms";
+    p_driverspecific_datetimeformat="D.M.Y h:m:s";
     
 }
 
