@@ -161,8 +161,8 @@ vector<hk_string>* hk_mdbconnection::driver_specific_dblist(void)
 	   stat(fname.c_str(),&statbuf);
             if (S_ISREG(statbuf.st_mode))
 	    {
-	    size_t p =datei.find(fileend);
-            if (p<datei.size())
+	    hk_string::size_type p =datei.find(fileend);
+            if (p!=hk_string::npos)
             {
                 datei.replace(p,datei.size()-p,"");
                 p_databaselist.insert(p_databaselist.end(),datei);
