@@ -18,7 +18,7 @@
 #ifdef __cplusplus
   extern "C" {
 #endif
-#include <mdbtools.h>
+#include "mdbtools/mdbtools.h"
 #ifdef __cplusplus
   }
 #endif
