@@ -57,7 +57,7 @@ bool hk_mysqlactionquery::driver_specific_execute(void)
 }
 
 
-bool hk_mysqlactionquery::driver_specific_sql(const char* s)
+bool hk_mysqlactionquery::driver_specific_sql(const char* )
 {
     return true;
 }
