@@ -1,5 +1,5 @@
 // ****************************************************************************
-// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
+// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
 // This file is part of the hk_mysqlclasses library.
 // This file may be distributed and/or modified under the terms of the
 // GNU Library Public License version 2 as published by the Free Software
@@ -10,7 +10,7 @@
 // ****************************************************************************
 #ifndef HK_MYSQLACTIONQUERY
 #define HK_MYSQLACTIONQUERY
-#include <hk_actionquery.h>
+#include "hk_actionquery.h"
 class hk_mysqldatabase;
 class hk_mysqlactionquery:public hk_actionquery
 {
