@@ -47,7 +47,6 @@ void hk_mysqldatabase::driver_specific_tablelist(void)
     MYSQL_RES* Res;
     MYSQL_ROW row;
     char *wild=NULL;
-    unsigned int i;
     p_tablelist.erase(p_tablelist.begin(),p_tablelist.end());
     if (p_mysqlconnection!=NULL)
     {
@@ -85,9 +84,9 @@ void hk_mysqldatabase::driver_specific_tablelist(void)
             if (Res==NULL) return ;
             while ((row=mysql_fetch_row(Res)))
             {
-                for (i=0; i<mysql_num_fields(Res);i++)
+                for (unsigned int o=0; o<mysql_num_fields(Res);o++)
                 {
-                    p_tablelist.insert(p_tablelist.end(),row[i]);
+                    p_tablelist.insert(p_tablelist.end(),row[o]);
                 }
             }
             mysql_free_result(Res);
