@@ -68,12 +68,12 @@ bool  hk_odbcconnection::driver_specific_connect()
         SQLRETURN res =SQLAllocHandle(SQL_HANDLE_DBC,p_odbcenvironment,&p_odbcconnectionhandle);
         res=SQLConnect(p_odbcconnectionhandle,
             (database()->name().size()>0?
-	    (SQLCHAR*)database()->name().c_str():
-	    (SQLCHAR*) defaultdatabase().c_str()
+	    (SQLCHAR*)const_cast<char*>(database()->name().c_str()):
+	    (SQLCHAR*) const_cast<char*>(defaultdatabase().c_str())
 	    )
 	    ,SQL_NTS,
-            (SQLCHAR*)user().c_str(),SQL_NTS,
-            (SQLCHAR*)password().c_str(),SQL_NTS
+            (SQLCHAR*)const_cast<char*>(user().c_str()),SQL_NTS,
+            (SQLCHAR*)const_cast<char*>(password().c_str()),SQL_NTS
             );
         p_connected=( res==SQL_SUCCESS||res==SQL_SUCCESS_WITH_INFO);
         if (!p_connected)
@@ -143,19 +143,19 @@ vector<hk_string>* hk_odbcconnection::driver_specific_dblist(void)
     const int buffergroesse=100;
     short int beschreibungslaenge;
     short int databasenamelaenge;
-    SQLCHAR database[buffergroesse];
+    SQLCHAR db[buffergroesse];
     SQLCHAR beschreibung[buffergroesse];
     next=SQL_FETCH_FIRST;
     int count =0;
     SQLRETURN nreturn;
     while (
         (nreturn=SQLDataSources(    p_odbcenvironment,next,
-        database,buffergroesse,&databasenamelaenge,
+        db,buffergroesse,&databasenamelaenge,
         beschreibung,buffergroesse,&beschreibungslaenge
         ))
         ==SQL_SUCCESS ||nreturn==SQL_SUCCESS_WITH_INFO)
     {
-        p_databaselist.insert(p_databaselist.end(),(char*)database);
+        p_databaselist.insert(p_databaselist.end(),(char*)db);
         next=SQL_FETCH_NEXT;
         count++;
     }
