@@ -132,6 +132,7 @@ bool hk_paradoxconnection::server_needs(need_enum t) const
     {
 //         case NEEDS_NOTHING:
 	case NEEDS_NULL_TERMINATED_SQL:
+	case NEEDS_DIRECTORY_AS_DATABASE:
             return true;
 
         default: return false;
@@ -193,7 +194,7 @@ vector<hk_string>* hk_paradoxconnection::driver_specific_dblist(void)
             if (S_ISDIR(statbuf.st_mode))
 	    {
                 hk_string n=entry->d_name;
-  	        size_t p =n.find(".db");
+  	        hk_string::size_type p =n.find(".db");
 		if (p==hk_string::npos)
 		   p =n.find(".DB");
 		if (p==hk_string::npos &&n!="output" &&n!="."&&n!="..")
