@@ -38,7 +38,7 @@ class hk_sqlite3connection: public hk_connection
         virtual hk_string drivername(void) const;
         virtual unsigned int    default_tcp_port(void) const;
 virtual        bool    create_database(const hk_string& dbase);
-virtual        bool    delete_database(const hk_string& dbase);
+virtual        bool    delete_database(const hk_string& dbase,enum_interaction c=interactive);
 virtual hk_string mimetype(void) const {return "application/x-sqlite3";}
 
     protected:
