@@ -118,13 +118,16 @@ int main(int argc, char** argv)
 
     if (arguments.query.size())
     {
-        hk_string query;
+        xmlNodePtr query;
         if (is_localfile(arguments.query))
-            load_file(arguments.query,query);
+        {
+            xmlDocPtr dp=xmlParseFile(arguments.query.c_str());
+            query=xmlDocGetRootElement(dp);
+        }
         else
-            query=u2l(db->load(arguments.query,ft_query));
+            query=db->xmlload(arguments.query,ft_query);
 
-        if (!query.size())
+        if (!query)
         {
             hk_class::show_warningmessage(hk_class::hk_translate("Queryfile couldn't be loaded or is empty"));
             exit(1);
