@@ -108,9 +108,9 @@ int main(int argc, char** argv)
         r->load_report(arguments.report);
     }
     else
-    {
-        hk_string report;
-        if (!load_file(arguments.report,report))
+    {    xmlDocPtr dp=xmlParseFile(arguments.report.c_str());
+        xmlNodePtr report=xmlDocGetRootElement(dp);
+        if (!report)
         {
             hk_class::show_warningmessage(hk_class::hk_translate("Reportfile couldn't be loaded"));
             exit(1);
